import com.whitesource.artifactory.plugin.engine.Boot
import com.whitesource.artifactory.plugin.engine.DiffendAgent
import com.whitesource.artifactory.plugin.engine.PluginAgent
import org.artifactory.fs.ItemInfo
import org.artifactory.repo.RepoPath
import org.artifactory.request.Request

def path = new File(ctx.artifactoryHome.etcDir, "plugins").toString()
Boot.init(log, repositories, searches, path)

def scaAgent = createPluginAgent()
def diffendAgent = createDiffendAgent()

/**
 * scanRepositoriesCron (java.lang.String) - A valid cron expression used to schedule job runs.
 * Modify this parameter to configure the desired schedule to scan your artifactory repositories.
 * See README.md for examples.
 */
def scanRepositoriesCron = "0 0 0 * * ?"
def DiffendScanCron = "0 0 0 * * ?"
def PropRefreshCron = "0 0/5 * * * ?" // every 5 min

jobs {
    scanRepositories(cron: scanRepositoriesCron) {
        scaAgent.runRepositoriesScan()
    }
    diffendScanRepositories(cron: DiffendScanCron) {
        diffendAgent.runPackagesScan()
    }
    refreshProperties(cron: PropRefreshCron){
        Boot.refreshProperties()
    }
}

download {
    beforeDownload { Request request, RepoPath repoPath ->
        scaAgent.beforeDownload(request, repoPath)
    }

    afterRemoteDownload { Request request, RepoPath repoPath ->
        asSystem {
            scaAgent.afterRemoteDownload(request, repoPath)
        }
    }

    beforeRemoteDownload { Request request, RepoPath repoPath ->
        asSystem {
            diffendAgent.beforeRemoteDownload(request, repoPath)
        }
    }
}

storage {
    afterCreate { ItemInfo item ->
        scaAgent.afterCreate(item.getRepoPath())
    }
}

def createPluginAgent() {
    new PluginAgent()
}

def createDiffendAgent() {
    def path = new File(ctx.artifactoryHome.etcDir, "plugins").toString()
    return new DiffendAgent(path)
}